@@ -194,39 +194,45 @@ var BuiltinFuncSignatures = map[string][]*FuncSignature{
 var BuiltinGlobalVariableTypes = map[string]ExprType{
 	// https://docs.github.com/en/actions/learn-github-actions/contexts#github-context
 	"github": NewStrictObjectType(map[string]ExprType{
-		"action":            StringType{},
-		"action_path":       StringType{},
-		"action_ref":        StringType{},
-		"action_repository": StringType{},
-		"action_status":     StringType{},
-		"actor":             StringType{},
-		"api_url":           StringType{},
-		"base_ref":          StringType{},
-		"env":               StringType{},
-		"event":             NewEmptyObjectType(), // Note: Stricter type check for this payload would be possible
-		"event_name":        StringType{},
-		"event_path":        StringType{},
-		"graphql_url":       StringType{},
-		"head_ref":          StringType{},
-		"job":               StringType{},
-		"ref":               StringType{},
-		"ref_name":          StringType{},
-		"ref_protected":     StringType{},
-		"ref_type":          StringType{},
-		"path":              StringType{},
-		"repository":        StringType{},
-		"repository_owner":  StringType{},
-		"repositoryurl":     StringType{}, // repositoryUrl
-		"retention_days":    NumberType{},
-		"run_id":            StringType{},
-		"run_number":        StringType{},
-		"run_attempt":       StringType{},
-		"server_url":        StringType{},
-		"sha":               StringType{},
-		"token":             StringType{},
-		"triggering_actor":  StringType{},
-		"workflow":          StringType{},
-		"workspace":         StringType{},
+		"action":              StringType{},
+		"action_path":         StringType{},
+		"action_ref":          StringType{},
+		"action_repository":   StringType{},
+		"action_status":       StringType{},
+		"actor":               StringType{},
+		"actor_id":            StringType{},
+		"api_url":             StringType{},
+		"base_ref":            StringType{},
+		"env":                 StringType{},
+		"event":               NewEmptyObjectType(), // Note: Stricter type check for this payload would be possible
+		"event_name":          StringType{},
+		"event_path":          StringType{},
+		"graphql_url":         StringType{},
+		"head_ref":            StringType{},
+		"job":                 StringType{},
+		"job_workflow_sha":    StringType{},
+		"ref":                 StringType{},
+		"ref_name":            StringType{},
+		"ref_protected":       StringType{},
+		"ref_type":            StringType{},
+		"path":                StringType{},
+		"repository":          StringType{},
+		"repository_id":       StringType{},
+		"repository_owner":    StringType{},
+		"repository_owner_id": StringType{},
+		"repositoryurl":       StringType{}, // repositoryUrl
+		"retention_days":      NumberType{},
+		"run_id":              StringType{},
+		"run_number":          StringType{},
+		"run_attempt":         StringType{},
+		"server_url":          StringType{},
+		"sha":                 StringType{},
+		"token":               StringType{},
+		"triggering_actor":    StringType{},
+		"workflow":            StringType{},
+		"workflow_ref":        StringType{},
+		"workflow_sha":        StringType{},
+		"workspace":           StringType{},
 	}),
 	// https://docs.github.com/en/actions/learn-github-actions/contexts#env-context
 	"env": NewMapObjectType(StringType{}), // env.<env_name>
@@ -255,7 +261,6 @@ var BuiltinGlobalVariableTypes = map[string]ExprType{
 		"temp":       StringType{},
 		"tool_cache": StringType{},
 		"debug":      StringType{},
-		"workspace":  StringType{},
 	}),
 	// https://docs.github.com/en/actions/learn-github-actions/contexts#secrets-context
 	"secrets": NewMapObjectType(StringType{}),
@@ -273,6 +278,8 @@ var BuiltinGlobalVariableTypes = map[string]ExprType{
 	// https://docs.github.com/en/actions/learn-github-actions/contexts#inputs-context
 	// https://docs.github.com/en/actions/learn-github-actions/reusing-workflows
 	"inputs": NewEmptyStrictObjectType(),
+	// https://docs.github.com/en/actions/learn-github-actions/contexts#vars-context
+	"vars": NewMapObjectType(StringType{}), // vars.<var_name>
 }
 
 // Semantics checker
