@@ -114,6 +114,11 @@ var popularActions = []*action{
 		tags: []string{"v1"},
 		next: "v2",
 	},
+	{
+		slug: "dtolnay/rust-toolchain",
+		tags: []string{"stable", "beta", "nightly"},
+		next: "",
+	},
 	{
 		slug: "actions-rs/clippy-check",
 		tags: []string{"v1"},
@@ -146,8 +151,8 @@ var popularActions = []*action{
 	},
 	{
 		slug: "actions/delete-package-versions",
-		tags: []string{"v1", "v2", "v3"},
-		next: "v4",
+		tags: []string{"v1", "v2", "v3", "v4"},
+		next: "v5",
 	},
 	{
 		slug: "actions/download-artifact",
@@ -195,8 +200,8 @@ var popularActions = []*action{
 	},
 	{
 		slug: "actions/stale",
-		tags: []string{"v1", "v2", "v3", "v4", "v5", "v6"},
-		next: "v7",
+		tags: []string{"v1", "v2", "v3", "v4", "v5", "v6", "v7"},
+		next: "v8",
 	},
 	{
 		slug: "actions/upload-artifact",
@@ -208,6 +213,11 @@ var popularActions = []*action{
 		tags: []string{"v1"},
 		next: "v2",
 	},
+	{
+		slug: "actions/dependency-review-action",
+		tags: []string{"v3"},
+		next: "v4",
+	},
 	{
 		slug: "aws-actions/configure-aws-credentials",
 		tags: []string{"v1"},
@@ -245,8 +255,8 @@ var popularActions = []*action{
 	},
 	{
 		slug: "dessant/lock-threads",
-		tags: []string{"v2", "v3"},
-		next: "v4"}, // v1 does not exist
+		tags: []string{"v2", "v3", "v4"},
+		next: "v5"}, // v1 does not exist
 	{
 		slug: "docker/build-push-action",
 		tags: []string{"v1", "v2", "v3"},
@@ -332,8 +342,8 @@ var popularActions = []*action{
 	},
 	{
 		slug: "goreleaser/goreleaser-action",
-		tags: []string{"v1", "v2", "v3"},
-		next: "v4",
+		tags: []string{"v1", "v2", "v3", "v4"},
+		next: "v5",
 	},
 	{
 		slug: "gradle/wrapper-validation-action",
@@ -373,8 +383,8 @@ var popularActions = []*action{
 	},
 	{
 		slug: "nwtgck/actions-netlify",
-		tags: []string{"v1"},
-		next: "v2",
+		tags: []string{"v1", "v2"},
+		next: "v3",
 	},
 	{
 		slug: "octokit/request-action",
